getControllerForUrl method
Retrieves the active controller for a given url, if assigned in the pool.
Implementation
VideoViewPlayerController? getControllerForUrl(String url) {
return _activeControllers[url];
}
Retrieves the active controller for a given url, if assigned in the pool.
VideoViewPlayerController? getControllerForUrl(String url) {
return _activeControllers[url];
}