MethodChannelVideoViewPlayer class
An implementation of VideoViewPlayerPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- VideoViewPlayerPlatform
- MethodChannelVideoViewPlayer
Constructors
- MethodChannelVideoViewPlayer()
- Default constructor for MethodChannelVideoViewPlayer.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
-
onNetworkTypeChanged
→ Stream<
String> -
Stream emitting real-time network connection type changes.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancelPrefetch(
String url) → Future< void> -
Cancels active prefetching for
url.override -
dispose(
int textureId) → Future< void> -
Disposes native player instance
textureId.override -
getNetworkType(
) → Future< String> -
Gets current network type string from native network detector.
override
-
getPlatformVersion(
) → Future< String?> -
Retrieves the host platform OS version string.
override
-
getPosition(
int textureId) → Future< int> -
Gets current playback position in milliseconds for player instance
textureId.override -
initialize(
String url) → Future< int> -
Initializes the native video player for
urland returns a hardware texture ID.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pause(
int textureId) → Future< void> -
Pauses playback on player instance with
textureId.override -
play(
int textureId) → Future< void> -
Starts playback on player instance with
textureId.override -
prefetch(
String url, int bytes) → Future< void> -
Triggers native prefetching of initial
bytesfor videourl.override -
seekTo(
int textureId, Duration position) → Future< void> -
Seeks player instance
textureIdtoposition.override -
setDataSource(
int textureId, String url) → Future< void> -
Swaps video data source for player instance
textureIdtourl.override -
setLooping(
int textureId, bool looping) → Future< void> -
Toggles looping for player instance
textureId.override -
setPlaybackSpeed(
int textureId, double speed) → Future< void> -
Sets playback speed for player instance
textureId.override -
setVolume(
int textureId, double volume) → Future< void> -
Sets audio volume for player instance
textureId.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited