VideoViewPlayerPlatform class abstract
The interface that implementations of video_view_player must implement.
- Inheritance
-
- Object
- PlatformInterface
- VideoViewPlayerPlatform
- Implementers
Constructors
- VideoViewPlayerPlatform()
- Constructs a VideoViewPlayerPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onNetworkTypeChanged
→ Stream<
String> -
Stream emitting real-time network connection type changes.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancelPrefetch(
String url) → Future< void> -
Cancels active prefetching for
url. -
dispose(
int textureId) → Future< void> -
Disposes native player instance
textureId. -
getNetworkType(
) → Future< String> - Gets current network type string from native network detector.
-
getPlatformVersion(
) → Future< String?> - Retrieves the host platform OS version string.
-
getPosition(
int textureId) → Future< int> -
Gets current playback position in milliseconds for player instance
textureId. -
initialize(
String url) → Future< int> -
Initializes the native video player for
urland returns a hardware texture ID. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pause(
int textureId) → Future< void> -
Pauses playback on player instance with
textureId. -
play(
int textureId) → Future< void> -
Starts playback on player instance with
textureId. -
prefetch(
String url, int bytes) → Future< void> -
Triggers native prefetching of initial
bytesfor videourl. -
seekTo(
int textureId, Duration position) → Future< void> -
Seeks player instance
textureIdtoposition. -
setDataSource(
int textureId, String url) → Future< void> -
Swaps video data source for player instance
textureIdtourl. -
setLooping(
int textureId, bool looping) → Future< void> -
Toggles looping for player instance
textureId. -
setPlaybackSpeed(
int textureId, double speed) → Future< void> -
Sets playback speed for player instance
textureId. -
setVolume(
int textureId, double volume) → Future< void> -
Sets audio volume for player instance
textureId. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ VideoViewPlayerPlatform
-
The default instance of VideoViewPlayerPlatform to use.
getter/setter pair