VideoViewPlayerPoolManager class
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
dispose()
→ Future<void>
-
Clear resources and dispose all controllers
override
-
getControllerForUrl(String url)
→ VideoViewPlayerController?
-
Retrieves the active controller for a URL, if any
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
prefetch(String url, {required int bytes})
→ Future<void>
-
Prefetch the first N bytes of a video to the cache
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateActiveIndex(int currentIndex)
→ Future<void>
-
Updates active controllers based on the current scroll index.
Instantiates at most 3 controllers, recycling idle controllers
using URL swapping rather than disposing and recreating them.